#!/bin/sh -efu

. livecd-functions
. alterator-net-functions
. shell-config
. shell-var

nm_controlled() {
	[ -s "/etc/net/ifaces/$1/options" ] || return 0	# presume "yes"
	shell_var_is_yes "$(shell_config_get "/etc/net/ifaces/$1/options" NM_CONTROLLED)"
}

transfer_etcnet() {
	[ -d "/etc/net/ifaces/$1" ] || return 1
	cp -a "/etc/net/ifaces/$1" $destdir/etc/net/ifaces/
}

transfer_runtime() {
	[ -n "$ip" ] || continue
	mkdir -p $destdir/etc/net/ifaces/$iface
	case "${BOOTPROTO:-}" in	# might be set by propagator (netboot)
		static)
			exec_chroot alterator-cmdline -l "/net-eth" action "write" \
				commit '#t' \
				name "$iface" \
				controlled 'etcnet' \
				configuration 'static' \
				ip "${IPADDR:-}" \
				mask "${NETBITS:-}" \
				default "${GATEWAY:-}" \
				search "${DOMAINNAME:-}" \
				dns "${DNS_SERVER:-}${DNS_SERVER2:+ $DNS_SERVER2}" \
				#
			;;
		*)
			shell_config_set "$iface/options" BOOTPROTO dhcp
			if [ -d "/sys/class/net/$iface/bridge" ]; then
				brif="$(netdev_list_brif "$iface")"
				shell_config_set $iface/options TYPE bri
				shell_config_set $iface/options HOST "$brif"
				mkdir -p "$brif"
				shell_config_set "$brif/options" TYPE eth
			else
				shell_config_set "$iface/options" TYPE eth
			fi
			;;
	esac
}

migrate() {
	for prefix in /var/lib /etc; do
		[ -d "$prefix$1" ] || continue
		rm -rf "$destdir$prefix$1"
		cp -a "$prefix$1" "$destdir$prefix$1"
	done
}

migrate NetworkManager
migrate connman

hostname=
[ -z "${HOSTNAME-}" -o \
  "${HOSTNAME-}" = localhost -o \
  "${HOSTNAME-}" = localhost.localdomain ] ||
	hostname="$HOSTNAME"

fallback=
for iface in $(list_eth); do
	ip="$(ip addr show $iface |
		sed -n 's,.*[[:space:]]inet[[:space:]]\+\([^/]\+\)/.*,\1,p' |
		head -n1)" # might be there upon netboot

	nm_controlled "$iface" ||
		transfer_etcnet "$iface" ||
		transfer_runtime "$iface"

	[ -z "$hostname" ] || continue
	h="$(hostinfo "$ip" |sed '/^hostname:[[:space:]]*/!d;s///;q')"
	if [ -n "$h" ]; then	# valid backresolved hostname
		hostname="$h"
	else			# current fallback hostname
		fallback="host-${ip##*.}${DOMAINNAME:+.$DOMAINNAME}"
	fi
done

[ -n "$hostname" ] ||
	hostname="$fallback"

[ -n "$hostname" ] ||
	shell_config_set $destdir/etc/sysconfig/network HOSTNAME "$hostname"
