#!/bin/sh

#     DESCRIPTION
#
#     Anti hook. Restore deleted kernel in /boot dir.

. livecd-functions

KPATH=
[ ! -d /image/boot ] || KPATH+="/image/boot"
[ ! -d /image/EFI/BOOT ] || KPATH+=" /image/EFI/BOOT"
[ ! -d /image/syslinux/alt0 ] || KPATH+=" /image/syslinux/alt0"
[ ! -d /image/alt0 ] || KPATH+=" /image/alt0"

[ -n "$KPATH" ] || fatal "can't find kernel image directories"

[ -n "$(find $KPATH -type f -name "vmlinu*" -o -name "image*" )" ] ||
	fatal "can't find kernel image"

verbose "Restore kernel image"

if ! [ -d "$target_dir" ]; then
    fatal "$target_dir doesn't exist"
fi

installkernel="/sbin/installkernel"

if ! [ -x "$installkernel" ]; then
    fatal "can't find $installkernel"
fi

arrange_kernel() {
	cp -a "$kimage" "$target_dir$kernel"
	exec_chroot "$installkernel" "$release" --nolaunch
}

kernels="$(exec_chroot rpm -ql $(rpm -qa "kernel-image*") | grep vmlinuz)"
for kernel in $kernels; do
	release=${kernel#*-}
	kimage="$(find $KPATH -type f -name vmlinuz-$release |tail -1)"
	[ -n "$kimage" ] ||
		kimage="$(find $KPATH -type f -name vmlinuz |tail -1)"
	arrange_kernel
done

# e2k
if [ -s "/image/alt0/vmlinux.0" ]; then
	kimage_e2k="/image/alt0/vmlinux.0"
elif [ -s "/image/boot/image" ]; then
	kimage_e2k="/image/boot/image"
fi

if [ -n "$kimage_e2k" ]; then
	release="$(uname -r)"
	kernel="$(rpm -qlf "/lib/modules/$release" |grep /boot/image)"
	kimage="$kimage_e2k"
	arrange_kernel
fi

exit 0
